==> tencentcloud-sdk-java-3.1.930-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeScreenRiskAssetsTopResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeScreenRiskAssetsTopResponse extends AbstractModel {

    /**
    * 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Chart")
    @Expose
    private ScreenNameValue [] Chart;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Chart 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
     */
    public ScreenNameValue [] getChart() {
        return this.Chart;
    }

    /**
     * Set 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
     * @param Chart 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setChart(ScreenNameValue [] Chart) {
        this.Chart = Chart;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeScreenRiskAssetsTopResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeScreenRiskAssetsTopResponse(DescribeScreenRiskAssetsTopResponse source) {
        if (source.Chart != null) {
            this.Chart = new ScreenNameValue[source.Chart.length];
            for (int i = 0; i < source.Chart.length; i++) {
                this.Chart[i] = new ScreenNameValue(source.Chart[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "Chart.", this.Chart);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1000-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeScreenRiskAssetsTopResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeScreenRiskAssetsTopResponse extends AbstractModel {

    /**
    * 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Chart")
    @Expose
    private ScreenNameValue [] Chart;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Chart 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
     */
    public ScreenNameValue [] getChart() {
        return this.Chart;
    }

    /**
     * Set 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
     * @param Chart 统计详情图标数据 Name：展示主机ip 和地域， value：事件数量
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setChart(ScreenNameValue [] Chart) {
        this.Chart = Chart;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeScreenRiskAssetsTopResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeScreenRiskAssetsTopResponse(DescribeScreenRiskAssetsTopResponse source) {
        if (source.Chart != null) {
            this.Chart = new ScreenNameValue[source.Chart.length];
            for (int i = 0; i < source.Chart.length; i++) {
                this.Chart[i] = new ScreenNameValue(source.Chart[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "Chart.", this.Chart);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
